@@ -2,8 +2,8 @@ xyplot.z <-
 function (xx, yy, zz, p = 0.5, sfact = 2.5, zmin = NA, zmax = NA, 
     log = NULL, xlim = NULL, ylim = NULL, xlab = deparse(substitute(xx)), 
     ylab = deparse(substitute(yy)), zlab = deparse(substitute(zz)), 
-    main = "", symcolr = 1, ifparams = FALSE, iflgnd = FALSE, 
-    title = deparse(substitute(zz)), ...) 
+    main = "", col = 1, iflgnd = FALSE, title = deparse(substitute(zz)), 
+    cex.lgnd = 0.8, ifparams = FALSE, cex.params = 0.8, ...) 
 {
     frame()
     temp.z <- remove.na(cbind(xx, yy, zz))
@@ -25,7 +25,7 @@ function (xx, yy, zz, p = 0.5, sfact = 2.5, zmin = NA, zmax = NA,
         log <- ""
     plot(x, y, type = "n", xlab = xlab, ylab = ylab, xlim = xlim, 
         ylim = ylim, log = log, main = banner, ...)
-    symbols(x, y, circles = rgz, inches = sfact * 0.05, fg = symcolr, 
+    symbols(x, y, circles = rgz, inches = sfact * 0.05, fg = col, 
         add = TRUE, ...)
     if (iflgnd) {
         if (!is.na(zmax)) 
@@ -36,13 +36,13 @@ function (xx, yy, zz, p = 0.5, sfact = 2.5, zmin = NA, zmax = NA,
         rgz <- syms(zval, zrange, p = p)
         zval <- signif(zval, 3)
         legend(locator(1), pch = rep.int(1, 5), pt.cex = rgz[1:5] * 
-            sfact/0.8, col = rep.int(symcolr, 5), paste(" ", 
-            zval[1:5]), cex = 0.8, title = title, ...)
+            sfact*1.25, col = rep.int(col, 5), paste(" ", 
+            zval[1:5]), cex = cex.lgnd, title = title)
     }
     if (ifparams) 
         text(locator(1), paste("p =", signif(p, 3), "& sfact =", 
             sfact, "\nz.max =", signif(z.max, 3), "; zmax =", 
             zmax, "\nz.min =", signif(z.min, 3), "; zmin =", 
-            zmin), cex = 0.8, adj = c(0, 1))
+            zmin), adj = c(0, 1), cex = cex.params, ...)
     invisible()
 }
